@@ -2,6 +2,12 @@ var path   = require('path'),
     less   = require('less'),
     source = '';
 
+function error(err, filename) {
+  err.filename = filename;
+  less.writeError(err);
+  process.exit(1);
+}
+
 process.stdin.resume();
 process.stdin.setEncoding('utf8');
 
@@ -12,11 +18,14 @@ process.stdin.on('data', function(chunk) {
 process.stdin.on('end', function() {
   var filename = process.argv[2],
       parser   = new(less.Parser)({paths: [path.dirname(filename)]});
-  parser.parse(source, function(err, tree) {
-    if (err) {
-      less.writeError(err);
-      process.exit(1);
-    }
-    process.stdout.write(tree.toCSS());
-  });
+  try {
+    parser.parse(source, function(err, tree) {
+      if (err) {
+        error(err, filename);
+      }
+      process.stdout.write(tree.toCSS());
+    });
+  } catch (err) {
+    error(err, filename);
+  }
 });
